@@ -5,22 +5,22 @@ build_time_vars = {'ABIFLAGS': 'm',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
  'BINLIBDEST': '/usr/local/lib/python3.7',
  'BLDLIBRARY': '-L. -lpython3.7m',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-              '-L/home/pea/pobj/Python-3.7.7/Python-3.7.7 -L/usr/local/lib/',
+              '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'mips64el-unknown-openbsd6.7',
+ 'BUILD_GNU_TYPE': 'arm-unknown-openbsd6.8',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC -O2 '
-           '-pipe -O2 -pipe',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
+           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -30,14 +30,14 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Wno-cast-function-type '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--with-ensurepip=no' '--enable-loadable-sqlite-extensions' "
                 "'--enable-shared' "
-                "'--srcdir=/home/pea/pobj/Python-3.7.7/Python-3.7.7' "
+                "'--srcdir=/usr/obj/ports/Python-3.7.9/Python-3.7.9' "
                 "'--with-fpectl' '--with-threads' '--enable-ipv6' "
                 "'--with-system-expat' '--with-system-ffi' "
                 "'--prefix=/usr/local' '--sysconfdir=/etc' "
@@ -48,8 +48,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.7m',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/home/pea/pobj/Python-3.7.7/Python-3.7.7/coverage.info',
- 'COVERAGE_REPORT': '/home/pea/pobj/Python-3.7.7/Python-3.7.7/lcov-report',
+ 'COVERAGE_INFO': '/usr/obj/ports/Python-3.7.9/Python-3.7.9/coverage.info',
+ 'COVERAGE_REPORT': '/usr/obj/ports/Python-3.7.9/Python-3.7.9/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -95,7 +95,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
- 'HAVE_ALIGNED_REQUIRED': 0,
+ 'HAVE_ALIGNED_REQUIRED': 1,
  'HAVE_ALLOCA_H': 0,
  'HAVE_ALTZONE': 0,
  'HAVE_ASINH': 1,
@@ -204,7 +204,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -252,7 +252,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -490,29 +490,29 @@ build_time_vars = {'ABIFLAGS': 'm',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'mips64el-unknown-openbsd6.7',
+ 'HOST_GNU_TYPE': 'arm-unknown-openbsd6.8',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.7m '
                    '/usr/local/include/python3.7m',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.7m',
- 'INSTALL': '/home/pea/pobj/Python-3.7.7/bin/install -c',
- 'INSTALL_DATA': '/home/pea/pobj/Python-3.7.7/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/home/pea/pobj/Python-3.7.7/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/home/pea/pobj/Python-3.7.7/bin/install -c -m 755',
- 'INSTALL_SHARED': '/home/pea/pobj/Python-3.7.7/bin/install -c -m 555',
+ 'INSTALL': '/usr/obj/ports/Python-3.7.9/bin/install -c',
+ 'INSTALL_DATA': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/usr/obj/ports/Python-3.7.9/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/usr/obj/ports/Python-3.7.9/bin/install -c -m 555',
  'INSTSONAME': 'libpython3.7m.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared -fPIC',
- 'LDFLAGS': '-L/usr/local/lib/ -L/home/pea/pobj/Python-3.7.7/Python-3.7.7 '
+ 'LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
             '-L/usr/local/lib/',
  'LDFLAGS_NODIST': '',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7m.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/ '
-             '-L/home/pea/pobj/Python-3.7.7/Python-3.7.7 -L/usr/local/lib/',
+             '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 -L/usr/local/lib/',
  'LDVERSION': '3.7m',
  'LIBC': '',
  'LIBDEST': '/usr/local/lib/python3.7',
@@ -608,42 +608,43 @@ build_time_vars = {'ABIFLAGS': 'm',
  'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
+                             '-O2 -pipe -O2 -pipe -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Wno-cast-function-type '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration -I. '
                              '-I./Include -I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC '
-              '-O2 -pipe -O2 -pipe',
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
+              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wno-cast-function-type '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   '
-                   '-fPIC -O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers -Wno-cast-function-type '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
+                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -I. -I./Include '
                    '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
-                    '-L/home/pea/pobj/Python-3.7.7/Python-3.7.7 '
+                    '-L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
                     '-L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-L/usr/local/lib/ -L/home/pea/pobj/Python-3.7.7/Python-3.7.7 '
+ 'PY_LDFLAGS': '-L/usr/local/lib/ -L/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
                '-L/usr/local/lib/',
  'PY_LDFLAGS_NODIST': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
-                        '-Wno-cast-function-type '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration -I. -I./Include '
                         '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
@@ -653,7 +654,7 @@ build_time_vars = {'ABIFLAGS': 'm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.7.7/Python-3.7.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
@@ -666,18 +667,18 @@ build_time_vars = {'ABIFLAGS': 'm',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37m',
@@ -695,10 +696,10 @@ build_time_vars = {'ABIFLAGS': 'm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.7.7/Python-3.7.7 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/home/pea/pobj/Python-3.7.7/Python-3.7.7 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/usr/obj/ports/Python-3.7.9/Python-3.7.9 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -720,8 +721,8 @@ build_time_vars = {'ABIFLAGS': 'm',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/home/pea/pobj/Python-3.7.7/Python-3.7.7',
- 'abs_srcdir': '/home/pea/pobj/Python-3.7.7/Python-3.7.7',
+ 'abs_builddir': '/usr/obj/ports/Python-3.7.9/Python-3.7.9',
+ 'abs_srcdir': '/usr/obj/ports/Python-3.7.9/Python-3.7.9',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
